==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/scripts/tk.php <==
<?php

return [
    'Names' => [
        'Arab' => 'Arap elipbiýi',
        'Armn' => 'Ermeni elipbiýi',
        'Beng' => 'Bengal elipbiýi',
        'Bopo' => 'Bopomofo elipbiýi',
        'Brai' => 'Braýl elipbiýi',
        'Cyrl' => 'Kiril elipbiýi',
        'Deva' => 'Dewanagari elipbiýi',
        'Ethi' => 'Efiop elipbiýi',
        'Geor' => 'Gruzin elipbiýi',
        'Grek' => 'Grek elipbiýi',
        'Gujr' => 'Gujarati elipbiýi',
        'Guru' => 'Gurmuhi elipbiýi',
        'Hanb' => 'Bopomofo han elipbiýi',
        'Hang' => 'Hangyl elipbiýi',
        'Hani' => 'Han elipbiýi',
        'Hans' => 'Ýönekeýleşdirilen',
        'Hant' => 'Adaty',
        'Hebr' => 'Ýewreý elipbiýi',
        'Hira' => 'Hiragana elipbiýi',
        'Hrkt' => 'Ýapon bogun elipbiýleri',
        'Jamo' => 'Jamo elipbiýi',
        'Jpan' => 'Ýapon elipbiýi',
        'Kana' => 'Katakana elipbiýi',
        'Khmr' => 'Khmer elipbiýi',
        'Knda' => 'Kannada elipbiýi',
        'Kore' => 'Koreý elipbiýi',
        'Laoo' => 'Laos elipbiýi',
        'Latn' => 'Latyn elipbiýi',
        'Mlym' => 'Malaýalam elipbiýi',
        'Mong' => 'Mongol elipbiýi',
        'Mymr' => 'Mýanma elipbiýi',
        'Orya' => 'Oriýa elipbiýi',
        'Sinh' => 'Singal elipbiýi',
        'Taml' => 'Tamil elipbiýi',
        'Telu' => 'Telugu elipbiýi',
        'Thaa' => 'Taana elipbiýi',
        'Thai' => 'Taý elipbiýi',
        'Tibt' => 'Tibet elipbiýi',
        'Zmth' => 'Matematiki belgiler',
        'Zsye' => 'Emoji',
        'Zsym' => 'Nyşanlar',
        'Zxxx' => 'Ýazuwsyz',
        'Zyyy' => 'Umumy',
    ],
];

==> symfony_5.4.23+dfsg.orig.tar.xz: symfony-5.4.23/src/Symfony/Component/Intl/Resources/data/scripts/tk.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'Adlam',
        'Arab' => 'Arap elipbiýi',
        'Aran' => 'Nastalik ýazuwy',
        'Armn' => 'Ermeni elipbiýi',
        'Beng' => 'Bengal elipbiýi',
        'Bopo' => 'Bopomofo elipbiýi',
        'Brai' => 'Braýl elipbiýi',
        'Cakm' => 'Çakma',
        'Cans' => 'Kanadanyň ýerlileriniň bogunlarynyň bitewileşdirilen ulgamy',
        'Cher' => 'Çeroki',
        'Cyrl' => 'Kiril elipbiýi',
        'Deva' => 'Dewanagari elipbiýi',
        'Ethi' => 'Efiop elipbiýi',
        'Geor' => 'Gruzin elipbiýi',
        'Grek' => 'Grek elipbiýi',
        'Gujr' => 'Gujarati elipbiýi',
        'Guru' => 'Gurmuhi elipbiýi',
        'Hanb' => 'Bopomofo han elipbiýi',
        'Hang' => 'Hangyl elipbiýi',
        'Hani' => 'Han elipbiýi',
        'Hans' => 'Ýönekeýleşdirilen',
        'Hant' => 'Adaty',
        'Hebr' => 'Ýewreý elipbiýi',
        'Hira' => 'Hiragana elipbiýi',
        'Hrkt' => 'Ýapon bogun elipbiýleri',
        'Jamo' => 'Jamo elipbiýi',
        'Jpan' => 'Ýapon elipbiýi',
        'Kana' => 'Katakana elipbiýi',
        'Khmr' => 'Khmer elipbiýi',
        'Knda' => 'Kannada elipbiýi',
        'Kore' => 'Koreý elipbiýi',
        'Laoo' => 'Laos elipbiýi',
        'Latn' => 'Latyn elipbiýi',
        'Mlym' => 'Malaýalam elipbiýi',
        'Mong' => 'Mongol elipbiýi',
        'Mtei' => 'Meýteý Maýek',
        'Mymr' => 'Mýanma elipbiýi',
        'Nkoo' => 'N’Ko',
        'Olck' => 'Ol Çiki',
        'Orya' => 'Oriýa elipbiýi',
        'Rohg' => 'Hanifi',
        'Sinh' => 'Singal elipbiýi',
        'Sund' => 'Sundanez ýazuwy',
        'Syrc' => 'Siriýa ýazuwy',
        'Taml' => 'Tamil elipbiýi',
        'Telu' => 'Telugu elipbiýi',
        'Tfng' => 'Tifinag ýazuwy',
        'Thaa' => 'Taana elipbiýi',
        'Thai' => 'Taý elipbiýi',
        'Tibt' => 'Tibet elipbiýi',
        'Vaii' => 'Waý ýazuwy',
        'Yiii' => 'Ýi ýazuwy',
        'Zmth' => 'Matematiki belgiler',
        'Zsye' => 'Emoji',
        'Zsym' => 'Nyşanlar',
        'Zxxx' => 'Ýazuwsyz',
        'Zyyy' => 'Umumy',
    ],
];
